########
fontwerk
########

All vendor-specific profiles such as the `fontwerk` one also include the checks from the :doc:`universal` profile. Fontwerk also includes most checks from the :doc:`googlefonts` profile, except these:

.. literalinclude:: ../../../../Lib/fontbakery/profiles/fontwerk.py
   :pyobject: leave_this_one_out

.. automodule:: fontbakery.profiles.fontwerk
   :members:
   :undoc-members:
